﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.RealVectorEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Problems.DataAnalysis;

// ReSharper disable once CheckNamespace
namespace HeuristicLab.Algorithms.EGO {
  [StorableClass]
  public abstract class InfillCriterionBase : ParameterizedNamedItem, IInfillCriterion {
    [Storable]
    public IRegressionSolution RegressionSolution { get; set; }
    [Storable]
    public bool ExpensiveMaximization { get; set; }
    [Storable]
    public RealVectorEncoding Encoding { get; set; }

    protected InfillCriterionBase(bool deserializing) : base(deserializing) { }
    protected InfillCriterionBase(InfillCriterionBase original, Cloner cloner) : base(original, cloner) {
      RegressionSolution = cloner.Clone(original.RegressionSolution);
      ExpensiveMaximization = original.ExpensiveMaximization;
      Encoding = cloner.Clone(original.Encoding);
    }
    protected InfillCriterionBase() { }

    public abstract double Evaluate(RealVector vector);
    //public abstract bool Maximization();

    public abstract void Initialize();
  }
}
